import React, {useEffect} from 'react';
import {useLocation} from 'react-router-dom';
import {addTrackHistory} from '../features/track-history/trackHistorySlice';
import {getTracksByQuery} from '../features/track/trackSlice';
import ITrackHistoryDto from '../interfaces/ITrackHistoryDto';
import {useAppDispatch, useAppSelector} from '../store/hooks';

const Tracks: React.FunctionComponent = (): React.ReactElement => {
	const {state} = useLocation();
	const {tracks} = useAppSelector((state) => state.track);
	const dispatch = useAppDispatch();
	const params = new URLSearchParams(window.location.search);
	const album = params.get('album');
	const {userLoggedIn} = useAppSelector((state) => state.user);

	useEffect(() => {
		dispatch(getTracksByQuery(album!));
	}, [dispatch]);

	const handleClick = async (trackId: string) => {
		const token = window.sessionStorage.getItem('token');
		const data: ITrackHistoryDto = {
			track: trackId,
			token: token!,
		};

		await dispatch(addTrackHistory(data));
	};

	return (
		<div>
			<h2 className="mt-0 mb-2 text-4xl font-medium leading-tight ">Tracks</h2>
			<h2>{state.artist}</h2>
			<h2>{state.album}</h2>
			<div className="flex flex-col gap-6 pt-4">
				{tracks.length ? (
					tracks.map((track) => {
						return (
							<div
								onClick={() =>
									userLoggedIn ? handleClick(track._id) : undefined
								}
								className="border border-solid color border-black p-4"
								key={track._id}
							>
								<p>Track number: {track.seq.toString()}</p>
								<p>Track name: {track.name}</p>
								<p>Track duration: {track.duration}</p>
							</div>
						);
					})
				) : (
					<p>No Tracks Yet</p>
				)}
			</div>
		</div>
	);
};

export default Tracks;
